package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.idcard.SysUserIdcard;

import java.util.List;


/**
 * 用户身份证信息Mapper接口
 * 
 * @author boman
 * @date 2024-04-22
 */
public interface SysUserIdcardMapper 
{
    /**
     * 查询用户身份证信息
     * 
     * @param userId 用户身份证信息主键
     * @return 用户身份证信息
     */
    public SysUserIdcard selectSysUserIdcardByUserId(Long userId);

    /**
     * 查询用户身份证信息列表
     * 
     * @param sysUserIdcard 用户身份证信息
     * @return 用户身份证信息集合
     */
    public List<SysUserIdcard> selectSysUserIdcardList(SysUserIdcard sysUserIdcard);

    /**
     * 新增用户身份证信息
     * 
     * @param sysUserIdcard 用户身份证信息
     * @return 结果
     */
    public int insertSysUserIdcard(SysUserIdcard sysUserIdcard);

    /**
     * 修改用户身份证信息
     * 
     * @param sysUserIdcard 用户身份证信息
     * @return 结果
     */
    public int updateSysUserIdcard(SysUserIdcard sysUserIdcard);

    /**
     * 删除用户身份证信息
     * 
     * @param userId 用户身份证信息主键
     * @return 结果
     */
    public int deleteSysUserIdcardByUserId(Long userId);

    /**
     * 批量删除用户身份证信息
     * 
     * @param userIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysUserIdcardByUserIds(Long[] userIds);
}
